docutils: Processing plaintext documentation into useful formats, such as HTML or LaTeX
=======================================================================================

Description
-----------

Docutils is a modular system for processing documentation into useful
formats, such as HTML, XML, and LaTeX. For input Docutils supports
reStructuredText, an easy-to-read, what-you-see-is-what-you-get
plaintext markup syntax.

License
-------

public domain, Python, 2-Clause BSD, GPL 3 (see COPYING.txt)

Upstream Contact
----------------

https://pypi.org/project/docutils/

Home Page: http://docutils.sourceforge.net/
